from copy import deepcopy


DEFAULTS = ('exact', 'disaggregation')

def match_fields(data, correspondence, field, match_types=DEFAULTS,
                 split_function=deepcopy, split_fields=None, log_function=None):
    """Match fields in ``data`` to new labels in ``correspondence``. Returns an iterator.

    By default, handles exact (1-to-1) matches, and disaggregation (1-to-N) matches. Aggregation of similar records (for M-to-N or N-to-1 matches) should take place after this function is run.

    Only matches one field at a time, you should call this for each field to be mapped.

    Arguments:

        * ``data``: An iterable of dictionaries.
        * ``correspondence``: A dictionary  of form
        * ``field``: A key in each element of ``data``.

    Returns an iterator of modified elements of ``data`` (or unmodified if no match can be made).

    """
    for row in data:
        if field not in row or row[field] not in correspondence:
            yield row

        matches = [obj
                   for obj in correspondence[row[field]
                   if obj['type'] in match_types]

        if len(matches) == 1:
            # No disaggregation needed

        else:
            for match in matches:
                new_row = split_function()







from setuptools import setup
import os

packages = []
root_dir = os.path.dirname(__file__)
if root_dir:
    os.chdir(root_dir)


# Probably should be changed, __init__.py is no longer required for Python 3
for dirpath, dirnames, filenames in os.walk('correspondentia'):
    # Ignore dirnames that start with '.'
    if '__init__.py' in filenames:
        pkg = dirpath.replace(os.path.sep, '.')
        if os.path.altsep:
            pkg = pkg.replace(os.path.altsep, '.')
        packages.append(pkg)


def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths


setup(
    name='correspondentia',
    version="0.0.1",
    packages=packages,
    author="Chris Mutel",
    author_email="cmutel@gmail.com",
    license=open('LICENSE').read(),
    # Only if you have non-python data (CSV, etc.). Might need to change the directory name as well.
    # package_data={'your_name_here': package_files(os.path.join('correspondentia', 'data'))},
    install_requires=[
    ],
    url="https://github.com/BONSAMURAIS/correspondentia",
    long_description=open('README.md').read(),
    description='your_name_here',
    classifiers=[
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Visualization',
    ],
)
